@@ -3,7 +3,7 @@ try:
     nlp=spacy.load('en_core_web_md')
 except Exception as e:
     import os
-    os.system('./spacy_downloader.sh')
+    print(os.popen('python3 -m spacy download en_core_web_md').read())
     nlp=spacy.load('en_core_web_md')
     
     # raise Exception(f"Failed with {e}, try running the following command - < python3 -m spacy download en_core_web_md > and reload your notebook")
